@@ -3,17 +3,14 @@
 
 import sys,time,random,base64,re
 from datetime import datetime, timedelta
-#from ACR.errors import *
-#from ACR.utils.hashcompat import md5_constructor
-#from ACR.utils.xmlextras import escapeQuotes, py2JSON
-#from ACR.utils import dicttree
-#from ACR.utils.timeutils import now
-#from ACR import acconfig
 from types import GeneratorType as generator
 from itertools import chain
 
 iterators=[list,generator,chain]
-
+try:
+	iterators+=[map]
+except:
+	pass
 #if hasattr(random, 'SystemRandom'):
 #	randrange=random.SystemRandom().randrange
 #else:
@@ -22,15 +19,14 @@ iterators=[list,generator,chain]
 #RE_PATH=re.compile("{\$([^}]+)}") # {$ foobar}
 #RE_PATH_split=re.compile("{\$[^}]+}") # {$ foobar}
 
-def skip(g,n):
-	if type(n) is not int:
-		raise TypeError("generator indices must be integers, not %s"%type(n).__name__)
-	j=0
-	for i in g:
-		if j is n:
-			return i
-		j+=1
-	raise IndexError("generator index out of range")
+from itertools import islice
+
+# islice=islice is an optimization
+def skip(iterable, n, islice=islice):
+	try:
+		return next(islice(iterable, n, None))
+	except StopIteration:
+		raise IndexError("generator index out of range")
 
 def py2JSON(o):
 	if o is True:
